import React, { useState, useRef, useMemo, useEffect } from 'react';
import styles from './index.less';
import {
  Menu,
  Grid,
  Drawer,
  Tooltip,
  Row,
  Col,
  Input,
  Modal,
  message,
} from 'antd';
import { history, Helmet } from 'umi';
import routes from '../../routes';
import {
  MenuOutlined,
  PlayCircleFilled,
  PhoneFilled,
  WechatFilled,
} from '@ant-design/icons';
import { Scrollbars } from 'react-custom-scrollbars';
import Footer from './footer';
import { doFetch } from '@/utils/doFetch';

const { useBreakpoint } = Grid;

const col = { xs: 24, sm: 24, md: 12, lg: 5, xl: 5, xxl: 5 },
  cola = { xs: 24, sm: 24, md: 24, lg: 4, xl: 4, xxl: 4 },
  cold = { xs: 24, sm: 24, md: 8, lg: 8, xl: 8, xxl: 8 },
  colds = { xs: 24, sm: 24, md: 24, lg: 16, xl: 16, xxl: 16 },
  cols = { xs: 24, sm: 24, md: 14, lg: 14, xl: 14, xxl: 14 };

const mapTree = (org) => {
  const haveChildren = Array.isArray(org.routes) && org.routes.length > 0;
  if (!org.name || org.hideInMenu) return;
  const children = haveChildren
    ? {
        children: org.routes.map((i) => mapTree(i)),
      }
    : {};

  return {
    key: org.path,
    label: org.name,
    type: org.type,
    ...children,
  };
};

const MenuRender = ({ arrs, mode, activeKey }) => {
  return (
    <Menu
      mode={mode ?? 'horizontal'}
      activeKey={activeKey}
      items={arrs}
      onClick={({ items, key, keyPath, domEvent }) => {
        if (key.includes('http')) {
          window.open(key);
        } else {
          history.push(key);
        }
      }}
    />
  );
};

function Layout({ children, location }) {
  const [collspan, setcollspan] = useState(false);
  const scrollRef = useRef();
  const screens = useBreakpoint();
  const [vals, setvals] = useState({});
  const [colls, setcolls] = useState(false);
  const [changes, setchanges] = useState(false);

  const arrs = useMemo(() => {
    let arr = [];
    routes.map((org) => {
      if (org.name) {
        arr.push(mapTree(org));
      }
    });
    return arr;
  }, []);

  useEffect(() => {
    scrollRef.current.view.scroll({
      top: 0,
      left: 0,
      behavior: 'smooth',
    });
  }, [location.pathname]);

  function setval(key, val) {
    setvals((s) => ({
      ...s,
      [key]: val,
    }));
  }

  const styled = useMemo(() => {
    if (changes) {
      return {
        width: '100%',
      };
    } else {
      return {
        position: 'fixed',
        bottom: 0,
        left: 0,
        width: '100%',
        zIndex: 222,
      };
    }
  }, [changes]);

  return (
    <div className={styles.container}>
      <Drawer
        open={collspan}
        title={false}
        maskClosable={true}
        onClose={() => {
          setcollspan(false);
        }}
        closable={false}
        width={260}
      >
        <MenuRender mode="inline" activeKey={location?.pathname} arrs={arrs} />
      </Drawer>
      <header>
        <div style={{ flex: 1 }}>
          {!screens.sm ? (
            <img
              src={require('@/assets/logo.svg')}
              alt=""
              style={{ width: '100%' }}
            />
          ) : (
            <img
              src={require('@/assets/logo.svg')}
              style={{ height: 52 }}
              alt=""
            />
          )}
        </div>

        <div className={styles.menu} style={{ flexShrink: 0 }}>
          {!screens.xl ? (
            <div className={styles.dll}>
              <MenuOutlined
                onClick={() => {
                  setcollspan(!collspan);
                }}
              />
              <Tooltip title="产品演示" placement="bottom">
                <PlayCircleFilled
                  style={{ fontSize: 20, color: '#000000' }}
                  onClick={async () => {
                    let res = await doFetch({
                      url: '/video/detail',
                      params: {},
                    });
                    Modal.info({
                      title: '产品演示',
                      width: '66vw',
                      content: (
                        <video
                          src={res?.data?.data?.videoUrl}
                          style={{ width: '100%' }}
                          controls
                          autoPlay
                        />
                      ),
                      okButtonProps: {
                        style: {
                          display: 'none',
                        },
                      },
                      maskClosable: true,
                    });
                  }}
                />
              </Tooltip>
            </div>
          ) : (
            <>
              <MenuRender
                activeKey={location?.pathname}
                arrs={arrs}
              ></MenuRender>
              <div
                className="center bglight"
                style={{
                  width: 130,
                  height: 80,
                  marginRight: -24,
                  color: '#fff',
                  cursor: 'pointer',
                  fontSize: 17,
                }}
                onClick={async () => {
                  let res = await doFetch({ url: '/video/detail', params: {} });
                  Modal.info({
                    title: '产品演示',
                    width: '66vw',
                    content: (
                      <video
                        src={res?.data?.data?.videoUrl}
                        style={{ width: '100%' }}
                        controls
                        autoPlay
                      />
                    ),
                    okButtonProps: {
                      style: {
                        display: 'none',
                      },
                    },
                    maskClosable: true,
                  });
                }}
              >
                <PlayCircleFilled
                  style={{ fontSize: 20, color: '#ffffff', marginRight: 6 }}
                />
                产品演示
              </div>
            </>
          )}
        </div>
      </header>
      <Scrollbars
        thumbMinSize={100}
        autoHide
        style={{
          width: '100%',
          height: 'calc( 100vh - 80px )',
          overflowX: 'hidden',
          position: 'relative',
        }}
        hideTracksWhenNotNeeded
        ref={scrollRef}
        className="olik"
        onScroll={(e) => {
          let divheight = document.getElementById('webFooter').clientHeight;
          let clientHeight = e.target.clientHeight;
          let scrollHeight = e.target.scrollHeight;

          if (e.target.scrollTop < scrollHeight - clientHeight - divheight) {
            setchanges(false);
          } else {
            setchanges(true);
          }
        }}
      >
        <div className="content">{children}</div>
        <div id="sets"></div>
        <div className={styles.navbar} style={styled} id="mine">
          {colls && (
            <Row
              style={{
                width: '100%',
                marginBottom: '1rem',
              }}
              className="submit"
              gutter={36}
            >
              <Col {...col} style={{ margin: '0.3rem 0' }}>
                <label htmlFor="contact">
                  <b>*</b> 联系人
                </label>
                <Input
                  name="contact"
                  value={vals.contact}
                  onChange={(e) => {
                    setval('contact', e.target.value);
                  }}
                />
              </Col>
              <Col {...col} style={{ margin: '0.3rem 0' }}>
                <label htmlFor="telephone">
                  <b>*</b> 联系方式
                </label>
                <Input
                  name="telephone"
                  value={vals.telephone}
                  onChange={(e) => {
                    setval('telephone', e.target.value);
                  }}
                />
              </Col>
              <Col {...col} style={{ margin: '0.3rem 0' }}>
                <label htmlFor="companyName">
                  <b>*</b> 公司名称
                </label>
                <Input
                  name="companyName"
                  value={vals.companyName}
                  onChange={(e) => {
                    setval('companyName', e.target.value);
                  }}
                />
              </Col>
              <Col {...col} style={{ margin: '0.3rem 0' }}>
                <label htmlFor="trade">所属行业（选填）</label>
                <Input
                  name="trade"
                  value={vals.trade}
                  onChange={(e) => {
                    setval('trade', e.target.value);
                  }}
                />
              </Col>
              <Col
                {...cola}
                style={{
                  display: 'flex',
                  justifyContent: 'center',
                  alignItems: 'flex-end',
                  margin: '0.3rem 0',
                  paddingRight: 0,
                }}
              >
                <div
                  className={`${styles.diybtn} bglightc`}
                  style={{
                    color: '#ffffff',
                    textShadow: '0px 0px 2px #999999',
                  }}
                  onClick={() => {
                    if (!vals.contact || !vals.telephone || !vals.companyName) {
                      message.warn('请填写必填项!');
                      return;
                    }
                    doFetch({
                      url: '/customerAdvice/add',
                      params: { ...vals },
                    }).then((res) => {
                      if (res.code == '0000') {
                        message.success(
                          '我们已收到您的申请，稍后将有专员联系您...',
                        );
                        setvals({});
                      }
                    });
                  }}
                >
                  提交
                </div>
              </Col>
            </Row>
          )}
          <Row
            gutter={0}
            style={{
              width: '100%',
            }}
          >
            <Col
              {...cola}
              className="center"
              style={{ fontSize: '0.8rem', margin: '0.3rem 0' }}
            >
              <div
                className="center"
                style={{
                  marginRight: 18,
                  border: '1px solid rgba(1, 92, 172, 1)',
                  color: 'rgba(1, 92, 172, 1)',
                  width: '1.5rem',
                  height: '1.5rem',
                  borderRadius: '50%',
                }}
              >
                <PhoneFilled rotate={90} />
              </div>
              025-86111901
            </Col>
            <Col
              {...colds}
              className="center"
              style={{
                fontSize: '0.8rem',
                cursor: 'pointer',
                margin: '0.3rem 0',
              }}
              onClick={() => {
                Modal.info({
                  title: '添加微信',
                  content: (
                    <img
                      src={require('@/assets/qrcode.png')}
                      style={{ width: '100%' }}
                    />
                  ),
                  okButtonProps: {
                    style: { display: 'none' },
                  },
                  maskClosable: true,
                });
              }}
            >
              <div
                className="center"
                style={{
                  marginRight: 18,
                  color: 'rgba(1, 92, 172, 1)',
                  backgroundColor: 'rgba(69, 176, 53, 1)',
                  width: '1.5rem',
                  height: '1.5rem',
                  borderRadius: '50%',
                }}
              >
                <WechatFilled style={{ color: '#FFFFFF' }} />
              </div>
              微信咨询
            </Col>
            <Col
              {...cola}
              className="center"
              style={{ fontSize: '0.8rem', margin: '0.3rem 0' }}
            >
              <div
                className={styles.diybtn}
                onClick={() => {
                  setcolls(!colls);
                  setvals({});
                }}
              >
                {!colls ? '免费体验' : '取消'}
              </div>
            </Col>
          </Row>
        </div>
        {!changes && (
          <div className={styles.navbar} id="mines">
            {colls && (
              <Row
                style={{
                  width: '100%',
                  marginBottom: '1rem',
                }}
                className="submit"
                gutter={36}
              >
                <Col {...col} style={{ margin: '0.3rem 0' }}>
                  <label htmlFor="contact">
                    <b>*</b> 联系人
                  </label>
                  <Input
                    name="contact"
                    value={vals.contact}
                    onChange={(e) => {
                      setval('contact', e.target.value);
                    }}
                  />
                </Col>
                <Col {...col} style={{ margin: '0.3rem 0' }}>
                  <label htmlFor="telephone">
                    <b>*</b> 联系方式
                  </label>
                  <Input
                    name="telephone"
                    value={vals.telephone}
                    onChange={(e) => {
                      setval('telephone', e.target.value);
                    }}
                  />
                </Col>
                <Col {...col} style={{ margin: '0.3rem 0' }}>
                  <label htmlFor="companyName">
                    <b>*</b> 公司名称
                  </label>
                  <Input
                    name="companyName"
                    value={vals.companyName}
                    onChange={(e) => {
                      setval('companyName', e.target.value);
                    }}
                  />
                </Col>
                <Col {...col} style={{ margin: '0.3rem 0' }}>
                  <label htmlFor="trade">所属行业（选填）</label>
                  <Input
                    name="trade"
                    value={vals.trade}
                    onChange={(e) => {
                      setval('trade', e.target.value);
                    }}
                  />
                </Col>
                <Col
                  {...cola}
                  style={{
                    display: 'flex',
                    justifyContent: 'center',
                    alignItems: 'flex-end',
                    margin: '0.3rem 0',
                  }}
                >
                  <div
                    className={`${styles.diybtn} bglightc`}
                    style={{
                      color: '#ffffff',
                      textShadow: '0px 0px 2px #999999',
                    }}
                    onClick={() => {
                      if (
                        !vals.contact ||
                        !vals.telephone ||
                        !vals.companyName
                      ) {
                        message.warn('请填写必填项!');
                        return;
                      }
                      doFetch({
                        url: '/customerAdvice/add',
                        params: { ...vals },
                      }).then((res) => {
                        if (res.code == '0000') {
                          message.success(
                            '我们已收到您的申请，稍后将有专员联系您...',
                          );
                        }
                      });
                    }}
                  >
                    提交
                  </div>
                </Col>
              </Row>
            )}
            <Row
              gutter={36}
              style={{
                width: '100%',
              }}
            >
              <Col
                {...cola}
                className="center"
                style={{ fontSize: '0.8rem', margin: '0.3rem 0' }}
              >
                <div
                  className="center"
                  style={{
                    marginRight: 18,
                    border: '1px solid rgba(1, 92, 172, 1)',
                    color: 'rgba(1, 92, 172, 1)',
                    width: '1.5rem',
                    height: '1.5rem',
                    borderRadius: '50%',
                  }}
                >
                  <PhoneFilled rotate={90} />
                </div>
                025-86111901
              </Col>
              <Col
                {...colds}
                className="center"
                style={{
                  fontSize: '0.8rem',
                  cursor: 'pointer',
                  margin: '0.3rem 0',
                }}
                onClick={() => {
                  Modal.info({
                    title: '添加微信',
                    content: (
                      <img
                        src={require('@/assets/qrcode.png')}
                        style={{ width: '100%' }}
                      />
                    ),
                    okButtonProps: {
                      style: { display: 'none' },
                    },
                    maskClosable: true,
                  });
                }}
              >
                <div
                  className="center"
                  style={{
                    marginRight: 18,
                    color: 'rgba(1, 92, 172, 1)',
                    backgroundColor: 'rgba(69, 176, 53, 1)',
                    width: '1.5rem',
                    height: '1.5rem',
                    borderRadius: '50%',
                  }}
                >
                  <WechatFilled style={{ color: '#FFFFFF' }} />
                </div>
                微信咨询
              </Col>
              <Col
                {...cola}
                className="center"
                style={{ fontSize: '0.8rem', margin: '0.3rem 0' }}
              >
                <div
                  className={styles.diybtn}
                  onClick={() => {
                    setcolls(!colls);
                  }}
                >
                  {!colls ? '免费体验' : '取消'}
                </div>
              </Col>
            </Row>
          </div>
        )}

        <Footer></Footer>
      </Scrollbars>
    </div>
  );
}

export default Layout;
